pub trait SignerKey:
Sign
+ Send
+ Sync {
// Required methods
fn fingerprint(&self) -> Vec<u8> ⓘ;
fn public_key(&self) -> Vec<u8> ⓘ;
}Expand description
Trait for keys that can be stored in a keychain.
This trait extends Sign with methods for key identification. All key
types in rust-bottle implement this trait, allowing them to be stored in
keychains.
Requirements
Sign: Must be able to sign messagesSend + Sync: Must be safe to send across threads